@@ -20,6 +20,7 @@
  */
 
 #include "kate_ctags_view.h"
+#include "kate_ctags_plugin.h"
 #include "kate_ctags_debug.h"
 
 #include <QFileInfo>
@@ -41,42 +42,65 @@ KateCTagsView::KateCTagsView(KTextEditor::Plugin *plugin, KTextEditor::MainWindo
 : QObject(mainWin)
 , m_proc(nullptr)
 {
-    KXMLGUIClient::setComponentName (QLatin1String("katectags"), i18n ("Kate CTag"));
-    setXMLFile( QLatin1String("ui.rc") );
+    KXMLGUIClient::setComponentName (QStringLiteral("katectags"), i18n ("Kate CTag"));
+    setXMLFile( QStringLiteral("ui.rc") );
 
-    m_toolView = mainWin->createToolView(plugin, QLatin1String("kate_plugin_katectagsplugin"),
+    m_toolView = mainWin->createToolView(plugin, QStringLiteral("kate_plugin_katectagsplugin"),
                                         KTextEditor::MainWindow::Bottom,
                                         QIcon::fromTheme(QStringLiteral("application-x-ms-dos-executable")),
                                         i18n("CTags"));
     m_mWin = mainWin;
 
-    QAction *back = actionCollection()->addAction(QLatin1String("ctags_return_step"));
+    QAction *back = actionCollection()->addAction(QStringLiteral("ctags_return_step"));
     back->setText(i18n("Jump back one step"));
     connect(back, &QAction::triggered, this, &KateCTagsView::stepBack);
 
-    QAction *decl = actionCollection()->addAction(QLatin1String("ctags_lookup_current_as_declaration"));
+    QAction *decl = actionCollection()->addAction(QStringLiteral("ctags_lookup_current_as_declaration"));
     decl->setText(i18n("Go to Declaration"));
     connect(decl, &QAction::triggered, this, &KateCTagsView::gotoDeclaration);
 
-    QAction *defin = actionCollection()->addAction(QLatin1String("ctags_lookup_current_as_definition"));
+    QAction *defin = actionCollection()->addAction(QStringLiteral("ctags_lookup_current_as_definition"));
     defin->setText(i18n("Go to Definition"));
     connect(defin, &QAction::triggered, this, &KateCTagsView::gotoDefinition);
 
-    QAction *lookup = actionCollection()->addAction(QLatin1String("ctags_lookup_current"));
+    QAction *lookup = actionCollection()->addAction(QStringLiteral("ctags_lookup_current"));
     lookup->setText(i18n("Lookup Current Text"));
     connect(lookup, &QAction::triggered, this, &KateCTagsView::lookupTag);
 
+    QAction *updateDB = actionCollection()->addAction(QStringLiteral("ctags_update_global_db"));
+    updateDB->setText(i18n("Configure ..."));
+    connect(updateDB, &QAction::triggered, this, [this, plugin] (bool) {
+        if (m_mWin) {
+            KateCTagsPlugin *p = static_cast<KateCTagsPlugin*>(plugin);
+            QDialog *confWin = new QDialog(m_mWin->window());
+            confWin->setAttribute(Qt::WA_DeleteOnClose);
+            auto confPage = p->configPage(0, confWin);
+            auto controls = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel, Qt::Horizontal, confWin);
+            connect(confWin, &QDialog::accepted, confPage, &KTextEditor::ConfigPage::apply);
+            connect(controls, &QDialogButtonBox::accepted, confWin, &QDialog::accept);
+            connect(controls, &QDialogButtonBox::rejected, confWin, &QDialog::reject);
+            auto layout = new QVBoxLayout(confWin);
+            layout->addWidget(confPage);
+            layout->addWidget(controls);
+            confWin->setLayout(layout);
+            confWin->setWindowTitle(i18nc("@title:window", "Configure CTags Plugin"));
+            confWin->setWindowIcon(confPage->icon());
+            confWin->show();
+            confWin->exec();
+        }
+    });
+
     // popup menu
     m_menu = new KActionMenu(i18n("CTags"), this);
-    actionCollection()->addAction(QLatin1String("popup_ctags"), m_menu);
+    actionCollection()->addAction(QStringLiteral("popup_ctags"), m_menu);
 
-    m_gotoDec=m_menu->menu()->addAction(i18n("Go to Declaration: %1",QString()), this, SLOT(gotoDeclaration()));
-    m_gotoDef=m_menu->menu()->addAction(i18n("Go to Definition: %1",QString()), this, SLOT(gotoDefinition()));
-    m_lookup=m_menu->menu()->addAction(i18n("Lookup: %1",QString()), this, SLOT(lookupTag()));
+    m_gotoDec=m_menu->menu()->addAction(i18n("Go to Declaration: %1",QString()), this, &KateCTagsView::gotoDeclaration);
+    m_gotoDef=m_menu->menu()->addAction(i18n("Go to Definition: %1",QString()), this, &KateCTagsView::gotoDefinition);
+    m_lookup=m_menu->menu()->addAction(i18n("Lookup: %1",QString()), this, &KateCTagsView::lookupTag);
 
     connect(m_menu->menu(), &QMenu::aboutToShow, this, &KateCTagsView::aboutToShow);
 
-    QWidget *ctagsWidget = new QWidget(m_toolView);
+    QWidget *ctagsWidget = new QWidget(m_toolView.data());
     m_ctagsUi.setupUi(ctagsWidget);
     m_ctagsUi.cmdEdit->setText(DEFAULT_CTAGS_CMD);
 
@@ -114,6 +138,7 @@ KateCTagsView::KateCTagsView(KTextEditor::Plugin *plugin, KTextEditor::MainWindo
 
     connect(m_mWin, &KTextEditor::MainWindow::unhandledShortcutOverride, this, &KateCTagsView::handleEsc);
 
+    m_toolView->layout()->addWidget(ctagsWidget);
     m_toolView->installEventFilter(this);
 
     m_mWin->guiFactory()->addClient(this);
@@ -125,9 +150,13 @@ KateCTagsView::KateCTagsView(KTextEditor::Plugin *plugin, KTextEditor::MainWindo
 /******************************************************************/
 KateCTagsView::~KateCTagsView()
 {
-    m_mWin->guiFactory()->removeClient( this );
+    if (m_mWin && m_mWin->guiFactory()) {
+        m_mWin->guiFactory()->removeClient( this );
+    }
 
-    delete m_toolView;
+    if (m_toolView) {
+        delete m_toolView;
+    }
 }
 
 /******************************************************************/
@@ -422,16 +451,16 @@ void KateCTagsView::jumpToTag(const QString &file, const QString &pattern, const
 
     if (unescaped.endsWith(QStringLiteral("$/"))) {
         reduced = unescaped.mid(2, unescaped.length() - 4);
-        escaped = QRegExp::escape(reduced);
+        escaped = QRegularExpression::escape(reduced);
         re_string = QStringLiteral("^%1$").arg(escaped);
     }
     else {
         reduced = unescaped.mid( 2, unescaped.length() -3 );
-        escaped = QRegExp::escape(reduced);
+        escaped = QRegularExpression::escape(reduced);
         re_string = QStringLiteral("^%1").arg(escaped);
     }
 
-    QRegExp re(re_string);
+    QRegularExpression re(re_string);
 
     // save current location
     TagJump from;
@@ -511,7 +540,7 @@ void KateCTagsView::updateSessionDB()
     }
 
 
-    QString command = QStringLiteral("%1 -f %2 %3").arg(m_ctagsUi.cmdEdit->text()).arg(m_ctagsUi.tagsFile->text()).arg(targets);
+    QString command = QStringLiteral("%1 -f %2 %3").arg(m_ctagsUi.cmdEdit->text(), m_ctagsUi.tagsFile->text(), targets);
 
     m_proc.start(command);
 
